@@ -75,6 +75,7 @@
 #include <kis_action_manager.h>
 #include <kis_action.h>
 #include "strokes/kis_color_picker_stroke_strategy.h"
+#include <kis_canvas_resource_provider.h>
 
 
 KisToolPaint::KisToolPaint(KoCanvasBase * canvas, const QCursor & cursor)
@@ -175,12 +176,22 @@ void KisToolPaint::activate(ToolActivation toolActivation, const QSet<KoShape*>
     KisTool::activate(toolActivation, shapes);
     connect(action("increase_brush_size"), SIGNAL(triggered()), SLOT(increaseBrushSize()), Qt::UniqueConnection);
     connect(action("decrease_brush_size"), SIGNAL(triggered()), SLOT(decreaseBrushSize()), Qt::UniqueConnection);
+
+    KisCanvasResourceProvider *provider = static_cast<KisCanvas2*>(canvas())->viewManager()->resourceProvider();
+    m_oldOpacity = provider->opacity();
+    provider->setOpacity(m_localOpacity);
 }
 
 void KisToolPaint::deactivate()
 {
+
     disconnect(action("increase_brush_size"), 0, this, 0);
     disconnect(action("decrease_brush_size"), 0, this, 0);
+
+    KisCanvasResourceProvider *provider = static_cast<KisCanvas2*>(canvas())->viewManager()->resourceProvider();
+    m_localOpacity = provider->opacity();
+    provider->setOpacity(m_oldOpacity);
+
     KisTool::deactivate();
 }
 
